@@ -15,27 +15,33 @@
 #' @seealso [testthat::expect_equivalent()]
 #' @importFrom testthat expect
 #' @export
-expect_json_equivalent <- function (object, expected, info=NULL,
-                                    label="object", expected.label="expected") {
-    comp <- json_compare(object, expected, check.attributes=FALSE)
-    expect(comp$equal, sprintf("%s not JSON-equivalent to %s.\n%s",
-        label, expected.label, comp$message), info = info)
-    invisible(object)
+expect_json_equivalent <- function(object,
+                                   expected,
+                                   info = NULL,
+                                   label = "object",
+                                   expected.label = "expected") {
+  comp <- json_compare(object, expected, check.attributes = FALSE)
+  expect(comp$equal, sprintf(
+    "%s not JSON-equivalent to %s.\n%s",
+    label, expected.label, comp$message
+  ), info = info)
+  invisible(object)
 }
 
 #' @importFrom testthat compare
-json_compare <- function (object, expected, check.attributes=FALSE) {
-    compare(object_sort(object), object_sort(expected),
-        check.attributes=check.attributes)
+json_compare <- function(object, expected, check.attributes = FALSE) {
+  compare(object_sort(object), object_sort(expected),
+    check.attributes = check.attributes
+  )
 }
 
-object_sort <- function (x) {
-    if (is.list(x)) {
-        x <- as.list(x) ## For S4 subclasses
-        if (!is.null(names(x))) {
-            x <- x[sort(names(x))]
-        }
-        return(lapply(x, object_sort))
+object_sort <- function(x) {
+  if (is.list(x)) {
+    x <- as.list(x) # For S4 subclasses
+    if (!is.null(names(x))) {
+      x <- x[sort(names(x))]
     }
-    return(x)
+    return(lapply(x, object_sort))
+  }
+  return(x)
 }
